@@ -1,6 +1,6 @@
 # PurpleWiki::InlineNode.pm
 #
-# $Id: InlineNode.pm,v 1.9 2004/01/21 23:24:08 cdent Exp $
+# $Id: InlineNode.pm,v 1.8 2003/08/18 07:10:53 eekim Exp $
 #
 # Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
 #
@@ -33,7 +33,7 @@ use 5.005;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.9.2';
+$VERSION = '0.9';
 
 ### constructor
 
@@ -45,7 +45,6 @@ sub new {
     # TODO: Type checking.
     $self->{type} = $options{type} ? $options{type} : undef;
     $self->{href} = $options{href} ? $options{href} : undef;
-    $self->{class} = $options{class} ? $options{class} : undef;
     $self->{content} = $options{content} ? $options{content} : undef;
     $self->{children} = $options{children} ? $options{children} : undef;
     bless $self, $this;
@@ -68,13 +67,6 @@ sub href {
     return $this->{href};
 }
 
-sub class {
-    my $this = shift;
-
-    $this->{class} = shift if @_;
-    return $this->{class};
-}
-
 sub content {
     my $this = shift;
 
