@@ -1,7 +1,7 @@
 # PurpleWiki::Page.pm
 # vi:ai:sw=4:ts=4:et:sm
 #
-# $Id: Page.pm,v 1.16 2004/01/21 23:24:08 cdent Exp $
+# $Id: Page.pm,v 1.13 2003/08/18 07:10:53 eekim Exp $
 #
 # Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
 #
@@ -34,16 +34,16 @@ use PurpleWiki::Database::Page;
 
 # mappings between PurpleWiki code and code within useMod
 
-# $Id: Page.pm,v 1.16 2004/01/21 23:24:08 cdent Exp $
+# $Id: Page.pm,v 1.13 2003/08/18 07:10:53 eekim Exp $
 
 use vars qw($MainPage $VERSION);
-$VERSION = '0.9.2';
+$VERSION = '0.9';
 
 sub exists {
     my $id = shift;
     my $config = shift;
 
-    $id =~ s|^/|$MainPage/| if defined($MainPage);
+    $id =~ s|^/|$MainPage/|;
     if ($config->FreeLinks) {
         $id = &FreeToNormal($id, $config);
     }
@@ -78,7 +78,7 @@ sub getInterWikiLink {
     
     my $results;
     $results = (&InterPageLink($id, $config))[0];
-    return $results ? _makeURL($results) : '';
+    return _makeURL($results);
 }
 
 sub getFreeLink {
@@ -164,18 +164,9 @@ sub GetPageLinkText {
 sub ScriptLink {
   my ($action, $text, $config) = @_;
 
-  my $baseUrl;
   my $scriptName = $config->ScriptName;
-  my $siteBase = $config->SiteBase;
-  if ($siteBase) {
-      $scriptName =~ s/^\///;
-      $siteBase =~ s/\/$//;
-      $baseUrl = "$siteBase/$scriptName";
-  }
-  else {
-      $baseUrl = $scriptName;
-  }
-  return "<a href=\"$baseUrl?$action\">$text</a>";
+
+  return "<a href=\"$scriptName?$action\">$text</a>";
 }
 
 sub GetEditLink {
