@@ -1,6 +1,6 @@
 # PurpleWiki::Tree.pm
 #
-# $Id: Tree.pm,v 1.30 2004/02/17 05:49:57 cdent Exp $
+# $Id: Tree.pm,v 1.27 2003/08/18 07:10:53 eekim Exp $
 #
 # Copyright (c) Blue Oxen Associates 2002-2003.  All rights reserved.
 #
@@ -34,7 +34,7 @@ use strict;
 use PurpleWiki::StructuralNode;
 
 use vars qw($VERSION);
-$VERSION = '0.9.2';
+$VERSION = '0.9';
 
 ### constructor
 
@@ -118,15 +118,13 @@ sub view {
     my ($driver, %params) = @_;
 
     $driver = lc($driver);
-    my $viewer = "PurpleWiki::View::$driver";
-    eval "require $viewer";
+    eval "require PurpleWiki::View::$driver";
     if ($@) { # driver not found
         # FIXME: Need better exception handling.
         return "Error: $driver View driver not found.";
     }
     else {
-        my $driverObj = $viewer->new(%params);
-        return $driverObj->view($this);
+        eval "return \&PurpleWiki::View::$driver\::view(\$this, \%params)";
     }
 }
 
