@@ -3,7 +3,7 @@
 #
 # wiki.pl - PurpleWiki
 #
-# $Id: wiki.pl,v 1.14 2004/02/07 02:20:57 cdent Exp $
+# $Id: wiki.pl,v 1.10 2003/07/19 09:08:41 eekim Exp $
 #
 # Copyright (c) Blue Oxen Associates 2002.  All rights reserved.
 #
@@ -38,7 +38,6 @@ use PurpleWiki::Database;
 use PurpleWiki::Database::Page;
 use PurpleWiki::Database::User;
 use PurpleWiki::Database::KeptRevision;
-use PurpleWiki::Search::Engine;
 use CGI;
 use CGI::Carp qw(fatalsToBrowser);
 
@@ -67,9 +66,6 @@ my $TimeZoneOffset;     # User's prefernce for timezone. FIXME: can we
 $wikiParser = PurpleWiki::Parser::WikiText->new;
 $config = new PurpleWiki::Config($CONFIG_DIR);
 
-# Set our umask if one was put in the config file. - matthew
-umask(oct($config->Umask)) if defined $config->Umask;
-
 # The "main" program, called from the end of this script file.
 sub DoWikiRequest {
   &InitRequest() or return;
@@ -512,10 +508,7 @@ sub DoHistory {
     config => $config);
   foreach my $section (reverse sort {$a->getRevision() <=> $b->getRevision()}
                     $keptRevision->getSections()) {
-    # If KeptRevision == Current Revision don't print it. - matthew
-    if ($section->getRevision() != $page->getSection()->getRevision()) {
-      $html .= &GetHistoryLine($id, $section, $canEdit, 0);
-    }
+    $html .= &GetHistoryLine($id, $section, $canEdit, 0);
   }
   print $html;
   print &GetCommonFooter();
@@ -774,23 +767,28 @@ sub GetHttpHeader {
 
 sub GetHtmlHeader {
   my ($title) = @_;
-  my ($dtd, $html);
+  my ($dtd, $bgcolor, $html, $bodyExtra);
 
   $html = '';
   $dtd = '-//IETF//DTD HTML//EN';
+  $bgcolor = 'white';  # Later make an option
   $html = qq(<!DOCTYPE HTML PUBLIC "$dtd">\n);
   $title = $q->escapeHTML($title);
-  $html .= "<html><head><title>$title</title>\n";
+  $html .= "<HTML><HEAD><TITLE>$title</TITLE>\n";
   if ($config->SiteBase ne "") {
-    $html .= qq(<base href=") . $config->SiteBase . qq(">\n);
+    $html .= qq(<BASE HREF=") . $config->SiteBase . qq(">\n);
   }
   if ($config->StyleSheet ne '') {
-    $html .= qq(<link rel="stylesheet" href=") . $config->StyleSheet .
-    qq(" />\n);
+    $html .= qq(<LINK REL="stylesheet" HREF=") . $config->StyleSheet . qq(">\n);
+  }
+  # Insert other header stuff here (like inline style sheets?)
+  $bodyExtra = '';
+  if ($bgcolor ne '') {
+    $bodyExtra = qq( BGCOLOR="$bgcolor");
   }
   # Insert any other body stuff (like scripts) into $bodyExtra here
   # (remember to add a space at the beginning to separate from prior text)
-  $html .= "</head><body>\n";
+  $html .= "</HEAD><BODY$bodyExtra>\n";
   return $html;
 }
 
@@ -918,8 +916,7 @@ sub WikiToHTML {
 
   my $wiki = $wikiParser->parse($pageText, config => $config, 'freelink' => $config->FreeLinks);
   my $url = $q->url(-full => 1) . '?' . $id;
-  return $wiki->view('wikihtml', config => $config, url => $url,
-                     pageName => $id);
+  return $wiki->view('wikihtml', config => $config, url => $url);
 }
 
 sub QuoteHtml {
@@ -1761,12 +1758,7 @@ sub DoSearch {
   }
   print &GetHeader('', &QuoteHtml("Search for: $string"), '');
   print '<br>';
-
-  # do the new pluggable search
-  my $search = new PurpleWiki::Search::Engine(config => $config);
-  $search->search($string);
-  print $search->asHTML();
-
+  &PrintPageList(&SearchTitleAndBody($string));
   print &GetCommonFooter();
 }
 
@@ -1894,15 +1886,12 @@ sub DoPost {
     $page->setPageCache('oldauthor', $section->getRevision());
   }
 
-  # I removed the if statement and moved the 3 lines of code down below 
-  #     -matthew
-  #
   # only save section if it is not the first
-  #if ($section->getRevision() > 0) {
-  #  $keptRevision->addSection($section, $Now);
-  #  $keptRevision->trimKepts($Now);
-  #  $keptRevision->save();
-  #}
+  if ($section->getRevision() > 0) {
+    $keptRevision->addSection($section, $Now);
+    $keptRevision->trimKepts($Now);
+    $keptRevision->save();
+  }
 
   if ($config->UseDiff) {
     # FIXME: how many args does it take to screw a pooch?
@@ -1916,9 +1905,6 @@ sub DoPost {
   # FIXME: redundancy in data structure here
   $section->setRevision($section->getRevision() + 1);
   $section->setTS($Now);
-  $keptRevision->addSection($section, $Now);
-  $keptRevision->trimKepts($Now);
-  $keptRevision->save();
   $page->setRevision($section->getRevision());
   $page->setTS($Now);
   $page->save();
@@ -1997,6 +1983,30 @@ END_MAIL_CONTENT
   }
 }
 
+sub SearchTitleAndBody {
+  my ($string) = @_;
+  my ($name, $freeName, @found);
+  my $page;
+  my $text;
+
+  foreach $name (&PurpleWiki::Database::AllPagesList($config)) {
+    $page = new PurpleWiki::Database::Page('id' => $name, 'now' => $Now, 
+      config => $config);
+    $page->openPage();
+    $text = $page->getText();
+    if (($text->getText() =~ /$string/i) || ($name =~ /$string/i)) {
+      push(@found, $name);
+    } elsif ($config->FreeLinks && ($name =~ m/_/)) {
+      $freeName = $name;
+      $freeName =~ s/_/ /g;
+      if ($freeName =~ /$string/i) {
+        push(@found, $name);
+      }
+    }
+  }
+  return @found;
+}
+
 # Note: all diff and recent-list operations should be done within locks.
 sub DoUnlock {
   my $LockMessage = 'Normal Unlock.';
